@@ -91,7 +91,12 @@ class Module:
             print("MQTT Disconnected", flush=True)
             client_id, login, password, host = self.get_connect_options()
             self.client.username_pw_set(login, password)
-            self.client.reconnect()
+            print(f"updated login={login} pw={password}", flush=True)
+            try:
+                self.client.reconnect()
+            except:
+                print(f"cannot reconnect")
+                return disconnect_handler(a, b, c)
 
         def connect_handler(a, b, c, d):
             print("MQTT Connected", flush=True)
